pub struct CcsAliasResolver { /* private fields */ }Expand description
CCS alias resolver that can be used by the agent registry.
Implementations
Sourceimpl CcsAliasResolver
impl CcsAliasResolver
Sourcepub const fn new(
aliases: HashMap<String, CcsAliasConfig>,
defaults: CcsConfig,
) -> Self
pub const fn new( aliases: HashMap<String, CcsAliasConfig>, defaults: CcsConfig, ) -> Self
Create a new CCS alias resolver with the given aliases.
Sourcepub fn try_resolve(&self, agent_name: &str) -> Option<AgentConfig>
pub fn try_resolve(&self, agent_name: &str) -> Option<AgentConfig>
Try to resolve an agent name as a CCS reference.
Returns Some(AgentConfig) if the name is a valid CCS reference.
For known aliases (or default ccs), uses the configured command.
For unknown aliases (e.g., ccs/random), generates a default CCS config
to allow direct CCS execution without configuration.
Returns None if the name is not a CCS reference (doesn’t start with “ccs”).