pub struct RealCatalogFetcher { /* private fields */ }Expand description
Production implementation of CatalogHttpClient that fetches from the network.
Implementations
Sourceimpl RealCatalogFetcher
impl RealCatalogFetcher
Sourcepub fn with_fetcher(fetcher: Arc<dyn HttpFetcher>) -> Self
pub fn with_fetcher(fetcher: Arc<dyn HttpFetcher>) -> Self
Build a catalog fetcher backed by the given HTTP capability.
Sourcepub fn with_http_fetcher<F>(fetcher: F) -> Selfwhere
F: HttpFetcher + 'static,
pub fn with_http_fetcher<F>(fetcher: F) -> Selfwhere
F: HttpFetcher + 'static,
Build a catalog fetcher from any type that implements [HttpFetcher].