Module validation

Module validation 

Startup validation for OpenCode agent references.

This module provides validation logic for checking that all opencode/* agent references in configured agent chains are valid (i.e., the provider and model exist in the OpenCode API catalog).

Validation errors include helpful suggestions for typos using Levenshtein distance matching.

Functions

get_opencode_refs
Get all OpenCode agent references from resolved drain bindings.
get_opencode_refs_in_resolved_drains
Get all OpenCode agent references from resolved drain bindings.
get_opencode_refs_legacy
Get all OpenCode agent references from the legacy fallback configuration.
validate_opencode_agents
Validate all OpenCode agent references in resolved drain bindings.
validate_opencode_agents_in_resolved_drains
Validate all OpenCode agent references in resolved drain bindings.
validate_opencode_agents_legacy
Validate all OpenCode agent references from the legacy fallback config.