Initialization boundary module.
This module provides boundary functions for pipeline initialization that involve imperative setup and configuration restoration. As a boundary module, it is exempt from functional programming lints.
Functions
- load_
agent_ registry_ boundary - Load agent registry with optional unified config.
- restore_
config_ from_ checkpoint - Restore configuration from a checkpoint by applying checkpoint overrides.