Module runtime_factory

Module runtime_factory 

Runtime object creation utilities.

This module provides boundary functions for creating runtime objects that require I/O operations (Timer, GitHelpers, PipelineRuntime). As a boundary module, it is exempt from functional programming lints.

Structs

PipelineRuntimeFactoryParams

Functions

create_agent_registry
create_cleanup_guard
create_effect_handler
create_git_helpers
create_main_effect_handler
create_pipeline_runtime
create_timer