Module cloud

Module cloud 

Cloud and git remote configuration types.

This module defines the cloud runtime configuration and git remote types used when Ralph is running in cloud-hosted mode.

Structs

CloudConfig
Cloud runtime configuration (internal).
CloudStateConfig
Cloud configuration that is safe to store in reducer state / checkpoints.
GitRemoteConfig
Git remote configuration (internal).
GitRemoteStateConfig

Enums

GitAuthMethod
GitAuthStateMethod