Configuration loading composition functions.
This module provides composition functions that wire pure domain functions to effectful capabilities.
Functions
- load_
config_ with_ default - Load a configuration value from the environment with a default.