verify_wrapper_cleaned

Function verify_wrapper_cleaned 

pub fn verify_wrapper_cleaned(repo_root: &Path) -> Vec<String>
Verify that the wrapper temp dir and track file have been cleaned up.

Returns a list of remaining artifacts for diagnostic purposes. An empty list means cleanup was successful.