pub fn event_loop_active_guard() -> EventLoopActiveGuardExpand description
Mark the reducer event loop as active for the duration of the returned guard.
pub fn event_loop_active_guard() -> EventLoopActiveGuardMark the reducer event loop as active for the duration of the returned guard.