request_user_interrupt

Function request_user_interrupt 

pub fn request_user_interrupt()
Request that the running pipeline treat the run as user-interrupted.

This is called by the Ctrl+C handler. The event loop is responsible for consuming the request and translating it into a reducer-visible transition.

Also sets the persistent USER_INTERRUPTED_OCCURRED flag, which is never cleared and allows shutdown code paths (e.g., capture_git_state) to detect the interrupt even after the event loop has consumed the pending request via take_user_interrupt_request().