Module boundary

Module boundary 

Boundary module for inherently iterative deduplication algorithms.

This module contains KMP and rolling hash implementations that are fundamentally iterative and cannot be cleanly expressed in functional style.

These functions are exempt from functional programming lints.

Structs

KMPMatcher
RollingHashWindow