Module stream_classifier

Module stream_classifier 

Stream event classifier for algorithmic detection of partial vs complete events.

This module provides a classifier that can distinguish between different types of streaming events without prior knowledge of the specific protocol. It uses heuristics based on JSON structure and field names to make conservative decisions about event classification.

Structs

ClassificationResult
Result of event classification
StreamEventClassifier
Stream event classifier

Enums

StreamEventType
Classification of a streaming event