Module streaming

Module streaming 

Streaming I/O utilities for runtime boundary.

This module provides streaming readers for process output.

Structs

CancelAwareReceiverBufRead
A reader that wraps a channel receiver with cancelation support.
StreamingLineReader
A line-oriented reader that processes data as it arrives.

Constants

MAX_BUFFER_SIZE
Maximum line size in bytes.
STDOUT_PUMP_CHANNEL_CAPACITY

Functions

cleanup_stdout_pump
create_stdout_channel
Create a bounded channel for stdout pumping.
spawn_stdout_pump
Spawn a thread to pump stdout data from a reader into a channel.