pub struct CancelAwareReceiverBufRead { /* private fields */ }Expand description
A reader that wraps a channel receiver with cancelation support.
This allows the reader to be stopped promptly when cancellation is requested, even if the underlying receive is blocking.
Implementations