Startup validation for OpenCode agent references.
This module provides validation logic for checking that all opencode/*
agent references in configured agent chains are valid (i.e., the provider
and model exist in the OpenCode API catalog).
Validation errors include helpful suggestions for typos using Levenshtein distance matching.
Functions
- get_
opencode_ refs - Get all
OpenCodeagent references from resolved drain bindings. - get_
opencode_ refs_ in_ resolved_ drains - Get all
OpenCodeagent references from resolved drain bindings. - get_
opencode_ refs_ legacy - Get all
OpenCodeagent references from the legacy fallback configuration. - validate_
opencode_ agents - Validate all
OpenCodeagent references in resolved drain bindings. - validate_
opencode_ agents_ in_ resolved_ drains - Validate all
OpenCodeagent references in resolved drain bindings. - validate_
opencode_ agents_ legacy - Validate all
OpenCodeagent references from the legacy fallback config.