String interning for deduplicating repeated strings in execution history.
This module provides a string pool that deduplicates commonly repeated strings
(like phase names and agent names) by storing them as Arc
Structs
- String
Pool - String pool for deduplicating commonly repeated strings in execution history.