pub struct HeartbeatGuard { /* private fields */ }Expand description
Guard for heartbeat background task.
Automatically stops the heartbeat when dropped.
Implementations
Sourceimpl HeartbeatGuard
impl HeartbeatGuard
Sourcepub fn start(reporter: Arc<dyn CloudReporter>, interval: Duration) -> Self
pub fn start(reporter: Arc<dyn CloudReporter>, interval: Duration) -> Self
Start a heartbeat background task.
The task will send heartbeats at the specified interval until the guard is dropped or the token is cancelled.