Cloud and git remote configuration types.
This module defines the cloud runtime configuration and git remote types used when Ralph is running in cloud-hosted mode.
Structs
- Cloud
Config - Cloud runtime configuration (internal).
- Cloud
State Config - Cloud configuration that is safe to store in reducer state / checkpoints.
- GitRemote
Config - Git remote configuration (internal).
- GitRemote
State Config