Stream event classifier for algorithmic detection of partial vs complete events.
This module provides a classifier that can distinguish between different types of streaming events without prior knowledge of the specific protocol. It uses heuristics based on JSON structure and field names to make conservative decisions about event classification.
Structs
- Classification
Result - Result of event classification
- Stream
Event Classifier - Stream event classifier
Enums
- Stream
Event Type - Classification of a streaming event