Streaming I/O utilities for runtime boundary.
This module provides streaming readers for process output.
Structs
- Cancel
Aware Receiver BufRead - A reader that wraps a channel receiver with cancelation support.
- Streaming
Line Reader - A line-oriented reader that processes data as it arrives.
Constants
- MAX_
BUFFER_ SIZE - Maximum line size in bytes.
- STDOUT_
PUMP_ CHANNEL_ CAPACITY
Functions
- cleanup_
stdout_ pump - create_
stdout_ channel - Create a bounded channel for stdout pumping.
- spawn_
stdout_ pump - Spawn a thread to pump stdout data from a reader into a channel.